<?PHP
/**
 * Contains a class for controlling the list of available attendance modes
 * to appointment / event.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Class containing available attendance modes.
 */
final class MDAppointmentAttendanceModeSet extends MDValueSet {

    public const MODES = [
        'offline',
        'online',
        'mixed',
    ];

    public const MODES_TO_SCHEMA_ORG = [
        'offline' => 'https://schema.org/OfflineEventAttendanceMode',
        'online' => 'https://schema.org/OnlineEventAttendanceMode',
        'mixed' => 'https://schema.org/MixedEventAttendanceMode',
    ];

    /**
     * Gets a list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string>
     */
    public static function getSortedList(MDTlLoader $tlLoader):array {
        return parent::getTlSortedList($tlLoader, self::MODES, "appointment_attendance_modes", "appointment_attendance_modes");

    }
}
