<?PHP
/**
 * Contains a list of states an object can be in for inventorization.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Contains a list of states an object can be in for inventorization.
 */
final class MDObjectStatusSet extends MDValueSet {

    public const DEFAULT_OBJECT_STATUS = 'owned';

    public const OBJECT_STATUS = [
        'owned',
        'permanent_loan',
        'third_party_property',
        'borrowed',
        'to_check_for_gift',
        'to_check',
        'deaccessed',
    ];

    /**
     * Gets an unsorted list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string>
     */
    public static function getUnsortedList(MDTlLoader $tlLoader):array {
        return parent::getTlUnsortedList($tlLoader, self::OBJECT_STATUS, "object_status", "object_status");

    }

    /**
     * Gets a list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string>
     */
    public static function getSortedList(MDTlLoader $tlLoader):array {
        return parent::getTlSortedList($tlLoader, self::OBJECT_STATUS, "object_status", "object_status");

    }
}
