<?PHP
/**
 * Class containing requirements for museum-digital generally.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Class containing requirements for museum-digital generally.
 */
final class MDRequirementsSet {

    // Newly created user account invites need to be accepted within
    // the given timespan. If they are not, the account will be ignored
    // and deleted.
    // 60 * 60 * 24 * 6 = 518400. 6 days.
    public const MAX_AGE_AFTER_USER_INVITE = 518400;

    // Object images need to be at least 500 px wide
    public const MIN_OBJECT_IMAGE_WIDTH = 540;

    // Object images need to be at least 500 px wide
    public const MIN_OBJECT_IMAGE_HEIGHT = 540;

    public const MAX_FILESIZE_PDF = 20000000;

    public const TIME_EARLIEST_YEAR = -6000000000;
    public const TIME_EARLIEST_DATE = '0001-01-01';
    public const TIME_LATEST_YEAR = 2099;
    public const TIME_LATEST_DATE = '9999-12-31';
    public const TIME_DEFAULT_DATE = '0001-01-01'; // Date to ignore in indexing

    public const MIMETYPES_USER_PROFILE_IMG = ['image/jpeg', 'image/jpg'];

    public const MIMETYPES_OBJECT_IMAGE = ['image/jpeg', 'image/jpg', 'image/png', 'image/webp'];
    public const MIMETYPES_OBJECT_PDF = ['application/pdf'];
    public const MIMETYPES_OBJECT_PROVENANCE_REPORT = ['application/pdf'];
    public const MIMETYPES_OBJECT_RESTORATION_REPORT = ['application/pdf', 'image/jpeg', 'image/png'];
    public const MIMETYPES_OBJECT_CONDITION_REPORT = ['application/pdf', 'image/jpeg', 'image/png'];

    public const MIMETYPES_OBJECT_DOCUMENT = ['image/jpeg', 'image/jpg', 'application/pdf'];

    public const MIMETYPES_COLLECTION_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_INSTITUTION_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_EXHIBITION_IMAGE = ['image/jpeg', 'image/jpg'];

    public const MIMETYPES_ARTICLE_ASSET = ['image/jpeg', 'image/jpg', 'image/png'];

    public const MIMETYPES_APPOINTMENT_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_APPOINTMENT_DOC_ASSET = ['application/pdf', 'image/jpeg', 'image/jpg', 'image/png'];

    public const MIMETYPES_PODCAST_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_PODCAST_EPISODE_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_TOUR_IMAGE = ['image/jpeg', 'image/jpg'];

    public const MIMETYPES_CATALOGUE_WORK_IMAGE = ['image/jpeg', 'image/jpg'];
    public const MIMETYPES_CATALOGUE_OBJECT_SUMMARY_IMAGE = ['image/jpeg', 'image/jpg'];

    public const EXTENSIONS_THREE_D_ZIP = ['obj', 'mtl', 'jpg', 'jpeg', 'png'];

}
