<?PHP
/**
 * Represents a most basic categorization of institutions using museum-digital.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Represents a most basic categorization of institutions using museum-digital.
 */
enum MDInstitutionBasicCategory implements MDValueEnumInterface, JsonSerializable {

    case museum;
    case archive;
    case library;
    case memorial_site;
    case private_collection;
    case university_collection;

    /**
     * Returns a value of this type based on a string.
     *
     * @param string $input Input to get a value from.
     *
     * @return MDInstitutionBasicCategory
     */
    public static function fromString(string $input):MDInstitutionBasicCategory {

        return match($input) {
            "museum" => self::museum,
            "archive" => self::archive,
            "library" => self::library,
            "memorial_site" => self::memorial_site,
            "private_collection" => self::private_collection,
            "university_collection" => self::university_collection,
            default => throw new MDpageParameterNotFromListException("Unknown institution category"),
        };

    }

    /**
     * Returns a value of this type based on an integer.
     *
     * @param integer $input Input to get a value from.
     *
     * @return MDInstitutionBasicCategory
     */
    public static function fromInt(int $input):MDInstitutionBasicCategory {

        return match($input) {
            0 => self::museum,
            1 => self::archive,
            2 => self::library,
            3 => self::memorial_site,
            4 => self::private_collection,
            5 => self::university_collection,
            default => throw new MDpageParameterNotFromListException("Unknown institution category"),
        };

    }

    /**
     * Lists all available names.
     *
     * @return array<string>
     */
    public static function caseNames():array {

        $output = [];

        $cases = self::cases();
        foreach ($cases as $case) {
            $output[] = $case->name;
        }

        return $output;

    }

    /**
     * Gets an unsorted list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string, string>
     */
    public static function getUnsortedList(MDTlLoader $tlLoader):array {
        return MDValueSet::getTlUnsortedList($tlLoader, self::caseNames(), "institution_basic_category_set", "institution_basic_category_set");

    }

    /**
     * Gets a sorted list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string, string>
     */
    public static function getSortedList(MDTlLoader $tlLoader):array {
        return MDValueSet::getTlSortedList($tlLoader, self::caseNames(), "institution_basic_category_set", "institution_basic_category_set");

    }

    /**
     * Lists all available names.
     *
     * @return array<integer>
     */
    public static function caseInts():array {

        $output = [];

        $cases = self::cases();
        foreach ($cases as $case) {
            $output[] = $case->toInt();
        }

        return $output;

    }

    /**
     * Returns integer representation of object record status.
     *
     * @return integer
     */
    public function toInt():int {

        return match($this) {
            self::museum => 0,
            self::archive => 1,
            self::library => 2,
            self::memorial_site => 3,
            self::private_collection => 4,
            self::university_collection => 5,
            # default => throw new MDpageParameterNotFromListException("Unknown object record status"),
        };

    }

    /**
     * Returns the name of the current value in translation.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return string
     */
    public function getTledName(MDTlLoader $tlLoader):string {

        return $tlLoader->tl("institution_basic_category_set", "institution_basic_category_set", $this->name);

    }

    /**
     * Provides the option to serialize as a string during json_encode().
     *
     * @return string
     */
    public function jsonSerialize():string {

        return $this->name;

    }
}
