<?PHP
/**
 * Represents a type of status that can be assigned to an object in the process
 * from identification to fixing or recognizing it is permanent.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Represents a type of status that can be assigned to an object in the process
 * from identification to fixing or recognizing it is permanent.
 */
enum MDObjectDamageStatus implements MDValueEnumInterface, JsonSerializable {

    case identified;
    case repair_possible;
    case repair_scheduled; // By conservator
    case repaired;
    case irreparable;

    /**
     * Returns a value of this type based on a string.
     *
     * @param string $input Input to get a value from.
     *
     * @return MDObjectDamageStatus
     */
    public static function fromString(string $input):MDObjectDamageStatus {

        return match($input) {
            'identified' => self::identified,
            'repair_possible' => self::repair_possible,
            'repair_scheduled' => self::repair_scheduled,
            'repaired' => self::repaired,
            'irreparable' => self::irreparable,
            default => throw new MDpageParameterNotFromListException("Unknown damage type"),
        };

    }

    /**
     * Lists all available names.
     *
     * @return array<string>
     */
    public static function caseNames():array {

        $output = [];

        $cases = self::cases();
        foreach ($cases as $case) {
            $output[] = $case->name;
        }

        return $output;

    }

    /**
     * Gets an unsorted list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string, string>
     */
    public static function getUnsortedList(MDTlLoader $tlLoader):array {
        return MDValueSet::getTlUnsortedList($tlLoader, self::caseNames(), "object_damage_status_set", "object_damage_status_set");

    }

    /**
     * Gets a sorted list of the entries in a translated version.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string, string>
     */
    public static function getSortedList(MDTlLoader $tlLoader):array {
        return MDValueSet::getTlSortedList($tlLoader, self::caseNames(), "object_damage_status_set", "object_damage_status_set");

    }

    /**
     * Returns the name of the current value in translation.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return string
     */
    public function getTledName(MDTlLoader $tlLoader):string {

        return $tlLoader->tl("object_damage_status_set", "object_damage_status_set", $this->name);

    }

    /**
     * Provides the option to serialize as a string during json_encode().
     *
     * @return string
     */
    public function jsonSerialize():string {

        return $this->name;

    }
}
